@@ -5,6 +5,7 @@ from scraper_helper.address import split_address
 from scraper_helper.address import split_address_canadian
 from scraper_helper.address import split_names
 from scraper_helper.html import html_decode
+from scraper_helper.scrapy import run_spider
 from scraper_helper.text import cleanup
 from scraper_helper.text import get_dict
 from scraper_helper.text import get_headers
@@ -14,7 +15,7 @@ from scraper_helper.url import get_query_str_val
 from scraper_helper.url import get_root_address
 from scraper_helper.url import strip_qs_params
 
-__version__ = '0.0.6'
+__version__ = '0.0.8'
 __all__ = [
     'change_param',
     'get_query_str_val',
@@ -30,4 +31,5 @@ __all__ = [
     'cleanup',
     'get_headers',
     'get_dict',
-    'headers']
+    'headers',
+    'run_spider']
